bl_info = {
    'name': 'Normalize all vertices weights',
    'author': 'Tlakali Studio',
    'version': (0, 1, 0),
    'blender': (2, 80, 0),
    'category': 'Mesh',
    'description': 'Normalize all vertices weights. Useful for assimp'
}

import bpy
import bmesh

class normvertices(bpy.types.Operator):
    bl_idname = 'v.normalize_all_vertices_weights'
    bl_label = 'Normalize all vertices weights'
    bl_options = {'REGISTER', 'UNDO'}

    def ShowMessageBox(message = "", title = "Message Box", icon = 'INFO'):
        def draw(self, context):
            self.layout.label(message)
        bpy.context.window_manager.popup_menu(draw, title = title, icon = icon)

    def execute(self, context):
        # Get the active object
        obj = bpy.context.active_object
        print(obj.name)
        
        bm = bmesh.from_edit_mesh(obj.data)

        for vertex in bm.verts:
            bm.select_history.add(vertex)
            bpy.ops.object.vertex_weight_normalize_active_vertex()
            print(bm.select_history.active)

        self.report({'INFO'}, str(bm.verts.__len__()) + " Vertices weights normalized [" + obj.name + "]")
        return {'FINISHED'}
    
    def invoke(self, context, event):
        return context.window_manager.invoke_props_dialog(self, width = 180)

def addToMenu(self, context):
    self.layout.operator("v.normalize_all_vertices_weights", icon = "GROUP_VERTEX")

def register():
    bpy.utils.register_class(normvertices)
    bpy.types.VIEW3D_MT_edit_mesh.append(addToMenu)

def unregister():
    bpy.utils.unregister_class(normvertices)
    bpy.types.VIEW3D_MT_edit_mesh.remove(addToMenu)

# This allows you to run the script directly from Blender's Text editor
# to test the add-on without having to install it.
#if __name__ == "__main__":
#    register()